@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permissio
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permissio
 import slixmpp
 from slixmpp.xmlstream import ElementBase, ET
 
@@ -14,6 +11,9 @@ class ChatState(ElementBase):
 
     """
     Example chat state stanzas:
+
+    ::
+
         <message>
           <active xmlns="http://jabber.org/protocol/chatstates" />
         </message>
@@ -22,16 +22,6 @@ class ChatState(ElementBase):
           <paused xmlns="http://jabber.org/protocol/chatstates" />
         </message>
 
-    Stanza Interfaces:
-        chat_state
-
-    Attributes:
-        states
-
-    Methods:
-        get_chat_state
-        set_chat_state
-        del_chat_state
     """
 
     name = ''
